==> haskell-newtype-0.2.2.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-newtype.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 newtype
version:              0.2.2.0
visibility:           public
id:                   newtype-0.2.2.0-3mUOwLZjJK4AuUUeEZZT47
key:                  newtype-0.2.2.0-3mUOwLZjJK4AuUUeEZZT47
license:              BSD-3-Clause
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel, Darius Jahandarie, Conor McBride
synopsis:             A typeclass and set of functions for working with newtypes.
description:
    Per Conor McBride, the '\''Newtype'\'' typeclass represents the packing and unpacking of a @newtype@, and allows you to operate under that @newtype@ with functions such as '\''ala'\''. See "Control.Newtype" for documentation and examples.

category:             Control
abi:                  ced6c2ce38b0ff3f9e66dc7ddde715a4
exposed:              True
exposed-modules:      Control.Newtype
import-dirs:          /usr/lib/ghc-9.6.6/site-local/newtype-0.2.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/newtype-0.2.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/newtype-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-newtype
hs-libraries:         HSnewtype-0.2.2.0-3mUOwLZjJK4AuUUeEZZT47
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-newtype/html/newtype.haddock
haddock-html:         /usr/share/doc/haskell-newtype/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-newtype-0.2.2.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-newtype.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 newtype
version:              0.2.2.1
visibility:           public
id:                   newtype-0.2.2.1-CfeJMJkAz9x3tnnjekkeBL
key:                  newtype-0.2.2.1-CfeJMJkAz9x3tnnjekkeBL
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Herbert Valerio Riedel, Darius Jahandarie, Conor McBride
synopsis:             A typeclass and set of functions for working with newtypes.
description:
    Per Conor McBride, the '\''Newtype'\'' typeclass represents the packing and unpacking of a @newtype@, and allows you to operate under that @newtype@ with functions such as '\''ala'\''. See "Control.Newtype" for documentation and examples.

category:             Control
abi:                  b59dcd96bfbcea9220d7a1f04c90c8fe
exposed:              True
exposed-modules:      Control.Newtype
import-dirs:          /usr/lib/ghc-9.6.6/site-local/newtype-0.2.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/newtype-0.2.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/newtype-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-newtype
hs-libraries:         HSnewtype-0.2.2.1-CfeJMJkAz9x3tnnjekkeBL
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-newtype/html/newtype.haddock
haddock-html:         /usr/share/doc/haskell-newtype/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
